"use strict";
const _ = require("lodash");
const micromatch = require("micromatch");
class AliasEvaluator {
    constructor(aliases) {
        this.aliases = new Map();
        _.forEach(aliases, (result, pattern) => {
            this.addAlias(pattern, result);
        });
    }
    addAlias(pattern, result) {
        if (this.aliases.has(pattern))
            throw new Error(`alias '${pattern}' already defined`);
        this.aliases.set(pattern, result);
    }
    evaluate(input) {
        for (const pair of this.aliases) {
            const matches = micromatch(pair[0]);
            if (matches.length > 0) {
                return pair[1];
            }
        }
        return input;
    }
}
exports.AliasEvaluator = AliasEvaluator;
