"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const _ = require("lodash");
const minimist = require("minimist");
class CommandEvaluator {
    constructor(commands) {
        this.commands = commands || {};
    }
    isDefined(path) {
        return _.has(this.commands, path);
    }
    hasCommand(path) {
        return _.has(this.commands, path) && typeof _.get(this.commands, path) === 'function';
    }
    hasCommands(path) {
        return _.has(this.commands, path) && _.isPlainObject(_.get(this.commands, path));
    }
    addCommand(path, callback) {
        if (_.has(this.commands, path))
            throw new Error(`command on '${path}' already taken`);
        _.set(this.commands, path, callback);
    }
    addCommands(commands) {
        _.forEach(this.commands, (callback, path) => {
            this.addCommand(path, callback);
        });
    }
    evaluate(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const argv = minimist(input.split(' '));
            let node = this.commands;
            while (typeof node !== 'function') {
                if (node === undefined || Object.keys(node).length === 0)
                    throw new Error(`command not found`);
                if (argv._.length === 0) {
                    console.log('Available commands:');
                    for (const key of Object.keys(node))
                        console.log(` - ${key}`);
                    return input;
                }
                node = node[argv._[0]];
                argv._.shift();
            }
            yield node(argv);
            return input;
        });
    }
}
exports.CommandEvaluator = CommandEvaluator;
